@@ -191,6 +191,12 @@ impl<Graph: StaticGraph> Omnitigs<Graph> {
         )
     }
 
+    /// Computes the maximal non-trivial omnitigs of the graph.
+    pub fn compute_non_trivial_only(graph: &Graph) -> Self {
+        let maximal_macrotigs = Macrotigs::compute(graph);
+        IncrementalHydrostructureMacrotigBasedNonTrivialOmnitigAlgorithm::compute_maximal_non_trivial_omnitigs(graph, &maximal_macrotigs)
+    }
+
     /// Computes the maximal trivial omnitigs of the given graph, including those that are subwalks of maximal non-trivial omnitigs.
     pub fn compute_trivial_only(graph: &Graph) -> Self {
         SccTrivialOmnitigAlgorithm::compute_maximal_trivial_omnitigs(graph, Omnitigs::default())
@@ -369,6 +375,15 @@ where
 
 impl<Graph: GraphBase> Eq for Omnitigs<Graph> where Graph::EdgeIndex: Eq {}
 
+impl<Graph: GraphBase> IntoIterator for Omnitigs<Graph> {
+    type Item = Omnitig<Graph>;
+    type IntoIter = std::vec::IntoIter<Self::Item>;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.omnitigs.into_iter()
+    }
+}
+
 /// A trait abstracting over the concrete algorithm used to compute maximal non-trivial omnitigs based on macrotigs.
 pub trait MacrotigBasedNonTrivialOmnitigAlgorithm<Graph: StaticGraph> {
     /// Compute the maximal non-trivial omnitigs of the given the maximal macrotigs.
